pub enum AttributeError {
NotFound(String),
ParamNotFound {
param: String,
attr: String,
},
InvalidParamValue {
param: String,
val: String,
attr: String,
},
UnsupportedFormat {
val: String,
attr: String,
},
UnexpectedTrailingItem {
val: String,
attr: String,
},
Other {
error: String,
attr: String,
},
}Expand description
Attribute error with specific details
Variants
NotFound(String)
If an Attribute is not found in a media or the session
ParamNotFound
If a parameter is missing in an attribute
InvalidParamValue
If a parameter value is not valid type or not in range
UnsupportedFormat
If an attribute is not in expected format
UnexpectedTrailingItem
If there are more than expected items trailing in the attribute parameters
Other
Unspecified error
Implementations
Sourceimpl AttributeError
impl AttributeError
pub fn is_attribute_not_found(&self) -> bool