Rtcp

Struct Rtcp 

pub struct Rtcp {
    pub port: u16,
    pub nettype: NetType,
    pub addrtype: AddrType,
    pub connection_address: String,
}
RTCP port number and address

To be used if not algorithmically derived from the RTP port described in the media line

See RFC 3605 Section 2.1

Fields

port: u16

Port used for the RTCP stream

nettype: NetType

Network Type

addrtype: AddrType

Address type

connection_address: String

Connection address: can be IP Address, unicast, multicast, … Conformity may be checked against the addrtype.

Implementations

Source

impl Rtcp

pub fn with_ip_addr(port: u16, connection_address: impl Into<IpAddr>) -> Self

Construct an Rtcp with the specified IP connection_address

pub fn new( port: u16, nettype: NetType, addrtype: AddrType, connection_address: impl ToString, ) -> Self

Construct an Rtcp

See also Rtcp::with_ip_addr

pub fn try_parse_connection_ip_address(&self) -> Result<IpAddr, &str>

Tries to parse the connection_address String of self as IpAddr

Returns the Ok with the parsed IpAddr or Err with the string address if parsing failed.

pub fn set_connection_ip_address( &mut self, connection_address: impl Into<IpAddr>, )

Sets the connection_address & addrtype of self from the specified IpAddr