Direct

Struct Direct 

pub struct Direct {
    pub offset: Option<u32>,
    pub rate: Option<Rate>,
}
Direct media clock with optional rate.

Fields

offset: Option<u32>rate: Option<Rate>

Implementations

Source

impl Direct

pub fn new() -> Self

Constructs a Direct media clock with no offset nor rate.

pub fn with_offset(offset: u32) -> Self

Constructs a Direct media clock with the specified offset.

pub fn set_offset(&mut self, offset: u32)

pub fn with_rate(rate: impl Into<Rate>) -> Self

Constructs a Direct media clock with the specified rate.

pub fn set_rate(&mut self, rate: impl Into<Rate>)

pub fn with_offset_and_rate(offset: u32, rate: impl Into<Rate>) -> Self

Constructs a Direct media clock with the specified offset & rate.

pub fn builder() -> Direct