pub struct MediaClockId {
pub src: bool,
pub tag: String,
}Expand description
Media clock ID with optional source prefix.
Fields
src: booltag: StringImplementations
Sourceimpl MediaClockId
impl MediaClockId
Sourcepub fn new(tag: impl ToString) -> Self
pub fn new(tag: impl ToString) -> Self
Constructs a MediaClockId with the specified tag and without the ‘src’ prefix.
Sourcepub fn new_with_src_prefix(tag: impl ToString) -> Self
pub fn new_with_src_prefix(tag: impl ToString) -> Self
Constructs a MediaClockId with the specified tag and with the ‘src’ prefix.
pub fn set_src_prefix(&mut self, src: bool)