pub struct Ntp {
pub server: NtpServerAddr,
}Expand description
NTP clock source with server address.
Fields
server: NtpServerAddrImplementations
Sourceimpl Ntp
impl Ntp
Sourcepub fn from_hostname(hostname: impl ToString) -> Ntp
pub fn from_hostname(hostname: impl ToString) -> Ntp
Constructs an Ntp clock source from the specified hostname.
Sourcepub fn from_hostname_with_port(hostname: impl ToString, port: u16) -> Ntp
pub fn from_hostname_with_port(hostname: impl ToString, port: u16) -> Ntp
Constructs an Ntp clock source from the specified hostname and port.
Sourcepub fn new_traceable() -> Ntp
pub fn new_traceable() -> Ntp
Constructs a traceable Ntp clock source.