ParserError

Enum ParserError 

pub enum ParserError {
Show 19 variants UnexpectedLine(usize, u8), InvalidLineFormat(usize, &'static str), InvalidFieldEncoding(usize, &'static str), InvalidFieldFormat(usize, &'static str), MissingField(usize, &'static str), FieldTrailingData(usize, &'static str), InvalidVersion(usize, Vec<u8>), MultipleVersions(usize), NoVersion, MultipleOrigins(usize), NoOrigin, MultipleSessionNames(usize), NoSessionName, MultipleSessionDescription(usize), MultipleUris(usize), MultipleConnections(usize), MultipleTimeZones(usize), MultipleMediaTitles(usize), MultipleKeys(usize),
}
Parsing errors that can be returned from Session::parse.

Variants



UnexpectedLine(usize, u8)

👎Deprecated:

This is no longer considered an error.

The given line started with an unexpected character.



InvalidLineFormat(usize, &'static str)

The given line was not formatted correctly.



InvalidFieldEncoding(usize, &'static str)

The given line contained an invalid encoding at the specified field.



InvalidFieldFormat(usize, &'static str)

The given line contained an invalid format at the specified field.



MissingField(usize, &'static str)

The given line was missing field data at the specified field.



FieldTrailingData(usize, &'static str)

The given line had some trailing data at the specified field.



InvalidVersion(usize, Vec<u8>)

The given version line did not contain a valid version number.



MultipleVersions(usize)

A second version line was found at the given line.



NoVersion

The SDP did not contain a version line.



MultipleOrigins(usize)

A second origin line was found at the given line.



NoOrigin

👎Deprecated:

This is no longer considered an error.

The SDP did not contain an origin line.



MultipleSessionNames(usize)

A second session name line was found at the given line.



NoSessionName

👎Deprecated:

This is no longer considered an error.

The SDP did not contain a session name line.



MultipleSessionDescription(usize)

A second session description line was found at the given line.



MultipleUris(usize)

A second URI line was found at the given line.



MultipleConnections(usize)

A second connection line was found at the given line.



MultipleTimeZones(usize)

A second time zone line was found at the given line.



MultipleMediaTitles(usize)

A second media title line was found at the given line.



MultipleKeys(usize)

A second key line was found at the given line.