pub struct Key {
pub method: String,
pub encryption_key: Option<String>,
}Expand description
Encryption key for the session or media.
Note: This field is obsolete and MUST NOT be used. It is included only for legacy reasons See RFC 8866 Section 5.12 for more details.
Fields
method: StringEncryption method that is used.
encryption_key: Option<String>Encryption key or information to obtain the encryption key.
Implementations
Sourceimpl Key
impl Key
pub fn new(method: KeyMethod) -> Self
Sourcepub fn with_encryption_key(
method: KeyMethod,
encryption_key: impl ToString,
) -> Self
pub fn with_encryption_key( method: KeyMethod, encryption_key: impl ToString, ) -> Self
Constructs a crate::Key and define its encryption_key.
Sourcepub fn try_parse_keymethod(&self) -> Result<KeyMethod, ParseEnumError>
pub fn try_parse_keymethod(&self) -> Result<KeyMethod, ParseEnumError>
Tries to parse the method String of self as KeyMethod
Sourcepub fn set_keymethod(&mut self, method: KeyMethod)
pub fn set_keymethod(&mut self, method: KeyMethod)
Sets the method String of self from the specified KeyMethod